interactive_adopt

Function interactive_adopt 

pub fn interactive_adopt(
    file_label: &str,
    original: &str,
    modified: &str,
) -> Result<Option<String>>
Interactively prompt the user to accept or reject each hunk of changes.

Returns Some(patched_content) if any hunks were accepted, None if all were rejected or the user quit early.