Module metadata

Module metadata 

Structs

ResolvedMetadata
Resolved metadata for a single file.

Functions

apply_ownership
Apply ownership (chown) to a file. Only applies fields that are Some.
read_file_metadata
Read the current metadata of a file on disk. Returns (owner_name, group_name, octal_mode).
resolve_metadata
Resolve what metadata to apply for a file, following the resolution order: