Module resolver

Module resolver 

Functions

resolve_packages
Resolve a list of requested packages into a fully-expanded, dependency-ordered list. Dependencies come before the packages that depend on them. Circular dependencies produce an error.