Structs
- Resolved
Metadata - Resolved metadata for a single file.
Functions
- apply_
ownership - Apply ownership (chown) to a file. Only applies fields that are Some.
- read_
file_ metadata - Read the current metadata of a file on disk. Returns (owner_name, group_name, octal_mode).
- resolve_
metadata - Resolve what metadata to apply for a file, following the resolution order: