Structs
- File
Action - Describes what to do with a single file during deployment.
Enums
- Entry
Kind - What kind of entry a file action represents, determining how it gets deployed.
Functions
- scan_
package - Scan a package directory and resolve overrides for the given host and roles.